# OpenSearch Views

## INTRODUCTION

The OpenSearch Views module provides integration between Drupal Views and
OpenSearch, enabling you to query and display data from OpenSearch indices
through the familiar Drupal Views interface.

This module is particularly useful for displaying JSON data from OpenSearch,
allowing you to select specific JSON fields to display in your views.

## REQUIREMENTS

* Drupal 9.x or 10.x
* Views module (included in Drupal core)
* OpenSearch PHP client library

## INSTALLATION

1. Install the module using Composer:
   ```
   composer require drupal/opensearch_views
   ```

2. Install the OpenSearch PHP client:
   ```
   composer require opensearch-project/opensearch-php
   ```

3. Enable the module through the UI or use Drush:
   ```
   drush en opensearch_views
   ```

## CONFIGURATION

1. Navigate to Configuration > Search and metadata > OpenSearch Views
   (/admin/config/search/opensearch_views)

2. Enter your OpenSearch connection details:
   - Host
   - Port
   - Username (if applicable)
   - Password (if applicable)
   - SSL options

3. Test the connection to ensure your Drupal site can communicate with your
   OpenSearch instance.

## USAGE

1. Create a new View
   - Select "OpenSearch" as the base table

2. In the View settings, choose:
   - The OpenSearch index to query
   - Optional query string to filter results

3. Add fields from your JSON documents:
   - Add an "OpenSearch: JSON Field" field
   - Select the JSON path to the data you want to display
   - Configure the display format

4. Add filters based on JSON fields:
   - Add an "OpenSearch: JSON Field" filter
   - Select the JSON path to filter on
   - Configure the filter criteria

5. Add sorting based on JSON fields:
   - Add an "OpenSearch: JSON Field" sort
   - Select the JSON path to sort by

## CUSTOMIZATION

Developers can extend this module by:

- Creating custom field formatters for specific JSON structures
- Adding query alter hooks to modify OpenSearch queries
- Implementing preprocessing hooks for results

## TROUBLESHOOTING

If you experience issues:

1. Verify your OpenSearch connection settings
2. Check that your OpenSearch index contains the expected JSON data
3. Examine the Drupal logs for any errors
4. Ensure the OpenSearch PHP client library is properly installed

## MAINTAINERS

Current maintainers:
* Adam Sanchez - https://www.drupal.org/u/asanchez75

This project has been sponsored by:
* https://landportal.org